@@ -313,6 +313,10 @@ class DetectTest(unittest.TestCase):
     def tearDown(self):
         shutil.rmtree(self.plugin_dir)
 
+        # most test cases switch the apt root, so the apt.Cache() cache becomes
+        # unreliable; reset it
+        UbuntuDrivers.detect.packages_for_modalias.cache_maps = {}
+
     @unittest.skipUnless(os.path.isdir('/sys/devices'), 'no /sys dir on this system')
     def test_system_modaliases_system(self):
         '''system_modaliases() for current system'''
@@ -742,6 +746,10 @@ APT::Get::AllowUnauthenticated "true";
         klass.plugin_dir = os.path.join(klass.chroot.path, 'detect')
         os.environ['UBUNTU_DRIVERS_DETECT_DIR'] = klass.plugin_dir
 
+        # avoid failures due to unexpected udevadm debug messages if kernel is
+        # booted with "debug"
+        os.environ['SYSTEMD_LOG_LEVEL'] = 'warning'
+
     @classmethod
     def tearDownClass(klass):
         klass.chroot.remove()
